@@ -10,17 +10,17 @@ from cloud_governance.common.mails.postfix import Postfix
 class ElasticUpload:
 
     def __init__(self):
-        self.__es_host = os.environ.get('es_host', '')
+        self.es_host = os.environ.get('es_host', '')
         self.__es_port = os.environ.get('es_port', '')
-        self._es_index = os.environ.get('es_index', '')
+        self.es_index = os.environ.get('es_index', '')
         self.account = os.environ.get('account', '').upper()
-        self._special_user_mails = os.environ.get('special_user_mails', '{}')
-        self._postfix_mail = Postfix()
-        self._mail_message = MailMessage()
-        if self.__es_host:
-            self._elastic_search_operations = ElasticSearchOperations(es_host=self.__es_host, es_port=self.__es_port)
+        self.special_user_mails = os.environ.get('special_user_mails', '{}')
+        self.postfix_mail = Postfix()
+        self.mail_message = MailMessage()
+        if self.es_host:
+            self.elastic_search_operations = ElasticSearchOperations(es_host=self.es_host, es_port=self.__es_port)
 
-    def es_upload_data(self, items: list, es_index: str):
+    def es_upload_data(self, items: list, es_index: str = ''):
         """
         This method upload data to elastic search
         @param items:
@@ -28,16 +28,20 @@ class ElasticUpload:
         @return:
         """
         try:
+            if not es_index:
+                es_index = self.es_index
             count = 0
             for item in items:
-                self._elastic_search_operations.upload_to_elasticsearch(index=es_index, data=item)
+                if not item.get('Account'):
+                    item['Account'] = self.account
+                self.elastic_search_operations.upload_to_elasticsearch(index=es_index, data=item)
                 count += 1
             if count > 0 and len(items) > 0:
                 logger.info(f'Data Uploaded to {es_index} successfully')
         except Exception as err:
             logger.info(f'Error raised {err}')
 
-    def _literal_eval(self, data: any):
+    def literal_eval(self, data: any):
         """
         This method convert string object into its original datatype
         ex: "{'Project': 'Cloud-Governance'}" --> {'Project': 'Cloud-Governance'}
