@@ -216,13 +216,16 @@ def main():
     es_doc_type = os.environ.get('es_doc_type', '')
     bucket = os.environ.get('bucket', '')
 
-    zombie_non_cluster_polices = ['ec2_idle', 'ec2_stop', 'ec2_run', 'ebs_in_use', 'ebs_unattached', 'empty_buckets', 'empty_roles', 'zombie_elastic_ips', 'zombie_nat_gateways', 'zombie_snapshots']
+    zombie_non_cluster_polices = ['ec2_idle', 'ec2_stop', 'ec2_run',
+                                  'ebs_in_use', 'ebs_unattached', 's3_inactive',
+                                  'empty_roles', 'ip_unattached', 'nat_gateway_unused',
+                                  'zombie_snapshots', 'skipped_resources', 'monthly_report']
     zombie_non_cluster_polices_runner = None
     is_zombie_non_cluster_polices_runner = policy in zombie_non_cluster_polices
     if is_zombie_non_cluster_polices_runner:
         zombie_non_cluster_polices_runner = ZombieNonClusterPolicies()
 
-    tag_ibm_classic_infrastructure_policies = ['tag_baremetal', 'tag_vm', 'ibm_cost_report']
+    tag_ibm_classic_infrastructure_policies = ['tag_baremetal', 'tag_vm', 'ibm_cost_report', 'ibm_cost_over_usage']
     tag_ibm_classic_infrastructure_runner = None
     is_tag_ibm_classic_infrastructure_runner = policy in tag_ibm_classic_infrastructure_policies
     if is_tag_ibm_classic_infrastructure_runner:
